/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.animation.messaging;

import java.util.Collections;
import java.util.List;
import org.robokind.api.animation.Animation;
import org.robokind.api.animation.player.AnimationJob;
import org.robokind.api.animation.player.AnimationPlayer;
import org.robokind.api.animation.protocol.AnimationEvent;
import org.robokind.api.animation.protocol.AnimationEvent.AnimationEventFactory;
import org.robokind.api.messaging.MessageSender;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class RemoteAnimationPlayerClient implements AnimationPlayer{
    private String myAnimationPlayerId;
    private String myRemotePlayerId;
    private MessageSender<AnimationEvent> myAnimationSender;
    private AnimationEventFactory myEventFactory;

    public RemoteAnimationPlayerClient(
            String animPlayerClientId, String animPlayerHostId){
        if(animPlayerClientId == null || animPlayerHostId == null){
            throw new NullPointerException();
        }
        myAnimationPlayerId = animPlayerClientId;
        myRemotePlayerId = animPlayerHostId;
    }
    
    @Override
    public String getAnimationPlayerId(){
        return myAnimationPlayerId;
    }
    
    public void setAnimationEventFactory(AnimationEventFactory factory){
        myEventFactory = factory;
    }
    
    public void setAnimationEventSender(MessageSender<AnimationEvent> sender){
        myAnimationSender = sender;
    }
    
    @Override
    public AnimationJob playAnimation(Animation animation) {
        if(myEventFactory == null || myAnimationSender == null){
            return null;
        }
        AnimationEvent event = 
                myEventFactory.createAnimationEvent(
                        myAnimationPlayerId, myRemotePlayerId, animation);
        myAnimationSender.sendMessage(event);
        return null;
    }

    @Override
    public AnimationJob playAnimation(Animation animation, Long start, Long stop) {
        animation.setStartTime(start);
        animation.setStopTime(stop);
        return playAnimation(animation);
    }

    @Override
    public List<AnimationJob> getCurrentAnimations() {
        return Collections.EMPTY_LIST;
    }

    @Override
    public void removeAnimationJob(AnimationJob job) {}
    
}
